@@ -19,14 +19,14 @@ Readonly::Hash our %VERT_CONV => (
 	'top' => 'flex-start',
 );
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my ($class, @params) = @_;
 
 	# Create object.
 	my ($object_params_ar, $other_params_ar) = split_params(
-		['css_container', 'css_inner', 'horiz_align', 'vert_align'], @params);
+		['css_container', 'css_inner', 'height', 'horiz_align', 'vert_align'], @params);
 	my $self = $class->SUPER::new(@{$other_params_ar});
 
 	# Container align.
@@ -37,6 +37,9 @@ sub new {
 	$self->{'css_container'} = 'container';
 	$self->{'css_inner'} = 'inner';
 
+	# Height.
+	$self->{'height'} = '100vh';
+
 	# Process params.
 	set_params($self, @{$object_params_ar});
 
@@ -92,7 +95,7 @@ sub _process_css {
 		['d', 'display', 'flex'],
 		['d', 'align-items', $VERT_CONV{$self->{'vert_align'}}],
 		['d', 'justify-content', $self->{'horiz_align'}],
-		['d', 'height', '100vh'],
+		['d', 'height', $self->{'height'}],
 		['e'],
 	);
 
@@ -147,6 +150,12 @@ CSS class for inner box in container.
 
 Default value is 'inner'.
 
+=item * C<height>
+
+Container height in CSS style.
+
+Default value is '100vh'.
+
 =item * C<horiz_align>
 
 Horizontal align.
@@ -286,6 +295,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
